Allocator

Struct Allocator 

pub struct Allocator;
An allocator.

Implementations

Source

impl Allocator

pub fn lock()

Locks a collector.

pub fn unlock()

Unlocks a collector.

pub unsafe fn initialize()

Initializes a collector.

Safety

This function must be called in a main thread.

pub unsafe fn register_current_thread() -> Result<(), Error>

Registers a current thread to a collector.

Safety

This function must not be called in a main thread.

pub unsafe fn set_stack_bottom(bottom: *const u8)

Sets a bottom of a stack.

You do not have to call this function in most cases. A collector detects the bottom on initialization automatically.

Safety

The bottom address must be valid.

pub unsafe fn unregister_current_thread()

Unregisters a current thread from a collector.

Safety

The thread must be registered already.

pub fn force_collect()

Runs a garbage collection forcibly.

pub unsafe fn register_finalizer( ptr: *const c_void, finalizer: extern "C" fn(*mut c_void, *mut c_void), client_data: *const c_void, )

Registers a finalizer of an object.

Safety

The given finalizer must not be null and handle pointers properly.