pub struct Allocator;Expand description
An allocator.
Implementations
Sourceimpl Allocator
impl Allocator
Sourcepub unsafe fn initialize()
pub unsafe fn initialize()
Sourcepub unsafe fn register_current_thread() -> Result<(), Error>
pub unsafe fn register_current_thread() -> Result<(), Error>
Registers a current thread to a collector.
Safety
This function must not be called in a main thread.
Sourcepub unsafe fn set_stack_bottom(bottom: *const u8)
pub unsafe fn set_stack_bottom(bottom: *const u8)
Sets a bottom of a stack.
You do not have to call this function in most cases. A collector detects the bottom on initialization automatically.
Safety
The bottom address must be valid.
Sourcepub unsafe fn unregister_current_thread()
pub unsafe fn unregister_current_thread()
Sourcepub fn force_collect()
pub fn force_collect()
Runs a garbage collection forcibly.